.. generate-parameter-files documentation master file, created by
   sphinx-quickstart on Fri Aug 26 20:40:46 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to generate-parameter-files's documentation!
====================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about
   installation
   stillingerweber
   vashishta
   tip4p
   usc
   info



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
